FilePicker class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearTemporaryFiles() Future<bool?>
Asks the underlying platform to remove any temporary files created by this plugin.
getDirectoryPath({String? dialogTitle, bool lockParentWindow = false, String? initialDirectory}) Future<String?>
Selects a directory and returns its absolute path.
pickFileAndDirectoryPaths({String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions}) Future<List<String>?>
Displays a dialog that allows the user to select both files and directories simultaneously, returning their absolute paths.
pickFiles({String? dialogTitle, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, dynamic onFileLoading(FilePickerStatus)?, int compressionQuality = 0, bool allowMultiple = false, bool withData = false, bool withReadStream = false, bool lockParentWindow = false, bool readSequential = false, bool cancelUploadOnWindowBlur = true}) Future<FilePickerResult?>
Retrieves the file(s) from the underlying platform
saveFile({String? dialogTitle, String? fileName, String? initialDirectory, FileType type = FileType.any, List<String>? allowedExtensions, Uint8List? bytes, bool lockParentWindow = false}) Future<String?>
Opens a save file dialog which lets the user select a file path and a file name to save a file.
skipEntitlementsChecks() Future<void>
Skips the entitlements checks on macOS, allowing the plugin to be used without Sandbox enabled.